Static Top Navbar Example for Bootstrap

##

主机名称:

操作系统类型 ：Linux（CentOS）

操作系统发行版本 ：6.4

设备架构 ：x86_64

处理器类型 ：x86_64

操作系统内核 ：2.6.32-358.el6.x86_64

storlever发布日期 ：#1 SMP Fri Feb 22 00:31:26 UTC 2013

uptime信息 ：03:24:04 up 2:29, 2 users, load average: 0.02, 0.01, 0.00

dist_id ：Final

#### cpu信息

cache_size： 6144 KB

cpu_MHz： 3073.183

processor： 4

model_name： Intel(R) Core(TM) i5-4570 CPU @ 3.20GHz

#### SELinux

运行情况: disabled

#### 总体cpu利用率

● cpu everage

● cpu #0

#### 内存信息

● used

● free

● cached

#### 清空缓存

确定要清空缓存吗？

#### SeLinux开关

确定要开启SELinux吗？

#### 修改主机名称

确定要修改主机名称吗？
Email address
Password
File input

Example block-level help text here.

Check me out
Email address
Password
Remember me
Email
Password
Remember me
Option one is this and that—be sure to include why it's great
Option one is this and that—be sure to include why it's great
Option two can be something else and selecting it will deselect option one
1 2 3

#### Collapsible Group Item #1

Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid. 3 wolf moon officia aute, non cupidatat skateboard dolor brunch. Food truck quinoa nesciunt laborum eiusmod. Brunch 3 wolf moon tempor, sunt aliqua put a bird on it squid single-origin coffee nulla assumenda shoreditch et. Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven't heard of them accusamus labore sustainable VHS.

#### Collapsible Group Item #2

Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid. 3 wolf moon officia aute, non cupidatat skateboard dolor brunch. Food truck quinoa nesciunt laborum eiusmod. Brunch 3 wolf moon tempor, sunt aliqua put a bird on it squid single-origin coffee nulla assumenda shoreditch et. Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven't heard of them accusamus labore sustainable VHS.

#### Collapsible Group Item #3

Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid. 3 wolf moon officia aute, non cupidatat skateboard dolor brunch. Food truck quinoa nesciunt laborum eiusmod. Brunch 3 wolf moon tempor, sunt aliqua put a bird on it squid single-origin coffee nulla assumenda shoreditch et. Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo. Leggings occaecat craft beer farm-to-table, raw denim aesthetic synth nesciunt you probably haven't heard of them accusamus labore sustainable VHS.

# | aaaa | bbb | cccc
--- | --- | --- | ---
1 | aaaa | bbb | cccc
2 | aaaa | bbb | cccc
3 | aaaa | bbb | cccc
4 | aaaa | bbb | cccc
5 | aaaa | bbb | cccc